"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.down = exports.up = void 0;
const api_1 = require("@deep-foundation/hasura/api");
const sql_1 = require("@deep-foundation/hasura/sql");
const trigger_1 = require("../trigger");
const table_1 = require("../table");
const relationships_1 = require("../relationships");
const api = new api_1.HasuraApi({
    path: process.env.MIGRATIONS_HASURA_PATH,
    ssl: !!+process.env.MIGRATIONS_HASURA_SSL,
    secret: process.env.MIGRATIONS_HASURA_SECRET,
});
const DEFAULT_SCHEMA = 'public';
const DEFAULT_MP_TABLE = 'mp_example__links__mp_md';
const DEFAULT_GRAPH_TABLE = 'mp_example__links_md';
const DEFAULT_ID_TYPE = 'integer';
exports.up = ({ SCHEMA = DEFAULT_SCHEMA, MP_TABLE = DEFAULT_MP_TABLE, GRAPH_TABLE = DEFAULT_GRAPH_TABLE, ID_TYPE = DEFAULT_ID_TYPE, trigger = trigger_1.Trigger({
    mpTableName: MP_TABLE,
    graphTableName: GRAPH_TABLE,
    id_type: DEFAULT_ID_TYPE,
    iteratorInsertBegin: ``,
    iteratorInsertEnd: '',
    groupInsert: '0',
    iteratorDeleteBegin: ``,
    iteratorDeleteEnd: '',
    groupDelete: '0',
    additionalFields: (action) => ',"custom"',
    additionalData: (action) => `,${action}`,
    isAllowSpreadFromCurrent: "CURRENT.dir = 'down'",
    isAllowSpreadCurrentTo: "CURRENT.dir = 'down'",
    isAllowSpreadToCurrent: "CURRENT.dir = 'up'",
    isAllowSpreadCurrentFrom: "CURRENT.dir = 'up'",
    isAllowSpreadToInCurrent: "flowLink.dir = 'down'",
    isAllowSpreadCurrentFromOut: "flowLink.dir = 'down'",
    isAllowSpreadFromOutCurrent: "flowLink.dir = 'up'",
    isAllowSpreadCurrentToIn: "flowLink.dir = 'up'",
}), } = {}) => __awaiter(void 0, void 0, void 0, function* () {
    yield api.sql(sql_1.sql `
    CREATE TABLE ${SCHEMA}."${GRAPH_TABLE}" (id ${ID_TYPE}, from_id ${ID_TYPE}, to_id ${ID_TYPE}, type_id ${ID_TYPE}, dir TEXT);
    CREATE SEQUENCE ${GRAPH_TABLE}_id_seq
    AS ${ID_TYPE} START WITH 1 INCREMENT BY 1 NO MINVALUE NO MAXVALUE CACHE 1;
    ALTER SEQUENCE ${GRAPH_TABLE}_id_seq OWNED BY ${SCHEMA}."${GRAPH_TABLE}".id;
    ALTER TABLE ONLY ${SCHEMA}."${GRAPH_TABLE}" ALTER COLUMN id SET DEFAULT nextval('${GRAPH_TABLE}_id_seq'::regclass);
  `);
    yield api.query({
        type: 'track_table',
        args: {
            schema: SCHEMA,
            name: GRAPH_TABLE,
        },
    });
    yield api.query({
        type: 'create_array_relationship',
        args: {
            table: GRAPH_TABLE,
            name: 'in',
            using: {
                manual_configuration: {
                    remote_table: {
                        schema: SCHEMA,
                        name: GRAPH_TABLE,
                    },
                    column_mapping: {
                        id: 'to_id',
                    },
                },
            },
        },
    });
    yield api.query({
        type: 'create_array_relationship',
        args: {
            table: GRAPH_TABLE,
            name: 'out',
            using: {
                manual_configuration: {
                    remote_table: {
                        schema: SCHEMA,
                        name: GRAPH_TABLE,
                    },
                    column_mapping: {
                        id: 'from_id',
                    },
                },
            },
        },
    });
    yield api.query({
        type: 'create_select_permission',
        args: {
            table: GRAPH_TABLE,
            role: 'guest',
            permission: {
                columns: '*',
                filter: {},
                limit: 999,
                allow_aggregations: true
            }
        }
    });
    yield api.query({
        type: 'create_select_permission',
        args: {
            table: GRAPH_TABLE,
            role: 'user',
            permission: {
                columns: '*',
                filter: {},
                limit: 999,
                allow_aggregations: true
            }
        }
    });
    yield table_1.up({ SCHEMA, MP_TABLE, customColumns: ',custom TEXT' });
    yield api.query({
        type: 'create_select_permission',
        args: {
            table: MP_TABLE,
            role: 'guest',
            permission: {
                columns: '*',
                filter: {},
                limit: 999,
                allow_aggregations: true
            }
        }
    });
    yield api.query({
        type: 'create_select_permission',
        args: {
            table: MP_TABLE,
            role: 'user',
            permission: {
                columns: '*',
                filter: {},
                limit: 999,
                allow_aggregations: true
            }
        }
    });
    yield relationships_1.up({ SCHEMA, MP_TABLE, GRAPH_TABLE });
    yield api.sql(trigger.upFunctionInsertNode());
    yield api.sql(trigger.upFunctionDeleteNode());
    yield api.sql(trigger.upTriggerDelete());
    yield api.sql(trigger.upTriggerInsert());
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__id_hash ON ${GRAPH_TABLE} USING hash (id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__from_id_hash ON ${GRAPH_TABLE} USING hash (from_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__from_id_btree ON ${GRAPH_TABLE} USING btree (from_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__to_id_hash ON ${GRAPH_TABLE} USING hash (to_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__to_id_btree ON ${GRAPH_TABLE} USING btree (to_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__type_id_hash ON ${GRAPH_TABLE} USING hash (type_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__type_id_btree ON ${GRAPH_TABLE} USING btree (type_id); `);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__dir_hash ON ${GRAPH_TABLE} USING hash (dir);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${GRAPH_TABLE}__dir_btree ON ${GRAPH_TABLE} USING btree (dir); `);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__id_hash ON ${MP_TABLE} USING hash (id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__item_id_hash ON ${MP_TABLE} USING hash (item_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__item_id_btree ON ${MP_TABLE} USING btree (item_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__path_item_id_hash ON ${MP_TABLE} USING hash (path_item_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__path_item_id_btree ON ${MP_TABLE} USING btree (path_item_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__path_item_depth_hash ON ${MP_TABLE} USING hash (path_item_depth);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__path_item_depth_btree ON ${MP_TABLE} USING btree (path_item_depth);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__root_id_hash ON ${MP_TABLE} USING hash (root_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__root_id_btree ON ${MP_TABLE} USING btree (root_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__position_id_hash ON ${MP_TABLE} USING hash (position_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__position_id_btree ON ${MP_TABLE} USING btree (position_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__group_id_hash ON ${MP_TABLE} USING hash (group_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__group_id_btree ON ${MP_TABLE} USING btree (group_id);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__insert_category_hash ON ${MP_TABLE} USING hash (insert_category);`);
    yield api.sql(`CREATE INDEX IF NOT EXISTS ${MP_TABLE}__insert_category_btree ON ${MP_TABLE} USING btree (insert_category);`);
});
exports.down = ({ SCHEMA = DEFAULT_SCHEMA, MP_TABLE = DEFAULT_MP_TABLE, GRAPH_TABLE = DEFAULT_GRAPH_TABLE, trigger = trigger_1.Trigger({
    mpTableName: MP_TABLE,
    graphTableName: GRAPH_TABLE,
    id_type: DEFAULT_ID_TYPE,
    iteratorInsertBegin: ``,
    iteratorInsertEnd: '',
    groupInsert: '0',
    iteratorDeleteBegin: ``,
    iteratorDeleteEnd: '',
    groupDelete: '0',
}), } = {}) => __awaiter(void 0, void 0, void 0, function* () {
    yield api.sql(trigger.downTriggerDelete());
    yield api.sql(trigger.downTriggerInsert());
    yield api.sql(trigger.downFunctionInsertNode());
    yield api.sql(trigger.downFunctionDeleteNode());
    yield relationships_1.down({ SCHEMA, MP_TABLE, GRAPH_TABLE });
    yield table_1.down({ SCHEMA, MP_TABLE });
    yield api.query({
        type: 'untrack_table',
        args: {
            table: {
                schema: SCHEMA,
                name: GRAPH_TABLE,
            },
        },
    });
    yield api.sql(sql_1.sql `
    DROP TABLE ${SCHEMA}."${GRAPH_TABLE}" CASCADE;
  `);
});
//# sourceMappingURL=1633562151439-multidirectional.js.map